Tree

Struct Tree 

pub struct Tree(pub Vec<Expression>);
A collection of expressions which may recursively form an expression tree

Seperate struct, use mutual recursion between tree and expressions to make parsing easier to implement. May combine them in the future.

Tuple Fields

0: Vec<Expression>

Implementations

Source

impl Tree

pub fn new() -> Tree

Create an empty tree