pub struct Stats {}Expand description
Stats which the interpreter uses to populate the gist expression
Fields
untracked: u16Number of untracked files which are new to the repository
added_staged: u16Number of files to be added
modified: u16Number of modified files which have not yet been staged
modified_staged: u16Number of staged changes to files
renamed: u16Number of renamed files
deleted: u16Number of deleted files
deleted_staged: u16Number of staged deletions
ahead: u16Number of commits ahead of the upstream branch
behind: u16Number of commits behind the upstream branch
conflicts: u16Number of unresolved conflicts in the repository
stashes: u16Number of stashes on the current branch
branch: StringThe branch name or other stats of the HEAD pointer
remote: StringThe of the upstream branch
Implementations