pub struct CompleteStyle {
pub fg: Option<Color>,
pub bg: Option<Color>,
pub bold: bool,
pub italics: bool,
pub underline: bool,
}Expand description
An aggregate unit which describes the sub total of a set of styles
use glitter_lang::ast::{Style, CompleteStyle, Color};
use Style::*;
use Color::*;
let complete: CompleteStyle = [Fg(Green), Bold].iter().collect();
assert_eq!(complete, CompleteStyle {
fg: Some(Green),
bold: true,
..Default::default()
});The conversion from a collection of styles is lossy:
use glitter_lang::ast::{Style, CompleteStyle, Color};
use Style::*;
use Color::*;
// Style::Reset at the final position is the same as
// CompleteStyle::default()
let reset_to_default: CompleteStyle = [Bg(Red), Reset].iter().collect();
assert_eq!(reset_to_default, CompleteStyle::default());
// Information about repeated styles is lost
let green: CompleteStyle = [Fg(Green)].iter().collect();
let green_repeat: CompleteStyle = std::iter::repeat(&Fg(Green)).take(10).collect();
assert_eq!(green, green_repeat);Fields
fg: Option<Color>bg: Option<Color>bold: boolitalics: boolunderline: boolImplementations